@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use Regexp::Grammars;
 
-our $VERSION = '0.29';
+our $VERSION = '0.32';
 
 sub new {
 	my ($class) = @_;
@@ -643,19 +643,22 @@ sub PT::ScalarAssignment::X {
     my $rhs = $class->{RHS}->X($className);
 
     my $scalarAssignment = $lhs . " = " . $rhs . ";\n";
-	return $scalarAssignment;
+    return $scalarAssignment;
 }
 
 sub PT::LHS::X {
     my ($class, $className) = @_;
     my $scalarVariable = $class->{ScalarVariable}->X($className);
+
     return $scalarVariable;
 }
 
 sub PT::ScalarVariable::X {
     my ($class, $className) = @_;
+
     my $scalarVariable = "\$";
     $scalarVariable .= $class->{''};
+
     return $scalarVariable;
 }
 
@@ -741,7 +744,7 @@ sub PT::FunctionReturn::X {
     }
 
     $functionReturn .= ")";
-	return $functionReturn;
+    return $functionReturn;
 }
 
 sub PT::ArrayElement::X {
@@ -810,9 +813,11 @@ sub PT::HashKey::X {
 
 sub PT::HashKeyString::X {
     my ($class, $className) = @_;
+
     my $hashKeyStringValue = "\"";
     $hashKeyStringValue .= $class->{HashKeyStringValue}->X($className);
     $hashKeyStringValue .= "\"";
+
     return $hashKeyStringValue;
 }
 
@@ -1192,6 +1197,25 @@ Lang::HL HL programming language.
 
 HL is a programming language.
 
+=head1 EXAMPLE
+
+	class NotePad {
+	    function notePad() {
+	        var text = "NotePad Example";
+	        class.text = text;
+	    }
+	}
+
+	class Main {
+	    parent(NotePad);
+
+	    function main() {
+	        class.notePad();
+	        var text = class.NotePad.text;
+	        print(text, "\n");
+	    }
+	}
+
 =head1 AUTHOR
 
 Rajkumar Reddy
